import React from 'react';
import NProgress from 'nprogress';
import Router from 'next/router';
import hoistStatics from 'hoist-non-react-statics';
import withStyles from '@material-ui/core/styles/withStyles';
import getDisplayName from '../util/getDisplayName'; // Disaply a progress bar between route transitions

NProgress.configure({
  template: `
    <div class="bar" role="bar">
      <dt></dt>
      <dd></dd>
    </div>
  `
});

Router.onRouteChangeStart = () => {
  NProgress.start();
};

Router.onRouteChangeComplete = () => {
  NProgress.done();
};

Router.onRouteChangeError = () => {
  NProgress.done();
};

const styles = theme => ({
  '@global': {
    '#nprogress': {
      pointerEvents: 'none',
      '& .bar': {
        position: 'fixed',
        background: theme.palette.type === 'light' ? theme.palette.common.black : theme.palette.common.white,
        borderRadius: 1,
        zIndex: theme.zIndex.tooltip,
        top: 0,
        left: 0,
        width: '100%',
        height: 2
      },
      '& dd, & dt': {
        position: 'absolute',
        top: 0,
        height: 2,
        boxShadow: `${theme.palette.type === 'light' ? theme.palette.common.black : theme.palette.common.white} 1px 0 6px 1px`,
        borderRadius: '100%',
        animation: 'nprogress-pulse 2s ease-out 0s infinite'
      },
      '& dd': {
        opacity: 0.6,
        width: 20,
        right: 0,
        clip: 'rect(-6px,22px,14px,10px)'
      },
      '& dt': {
        opacity: 0.6,
        width: 180,
        right: -80,
        clip: 'rect(-6px,90px,14px,-6px)'
      }
    },
    '@keyframes nprogress-pulse': {
      '30%': {
        opacity: 0.6
      },
      '60%': {
        opacity: 0
      },
      to: {
        opacity: 0.6
      }
    }
  }
});
/**
 * inject nprogress with NextJs.Router
 */


const withProgressBar = BaseComponent => {
  const InjectProgressBar = props => React.createElement(BaseComponent, props); // wrap displayName for easier debug


  InjectProgressBar.displayName = `withProgressBar(${getDisplayName(BaseComponent)})`; // hoist all static functions

  hoistStatics(InjectProgressBar, BaseComponent);
  return withStyles(styles)(InjectProgressBar);
};

export default withProgressBar;