function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import { Head, Main, NextScript } from 'next/document';
import ServerStyleSheets from '@material-ui/styles/ServerStyleSheets';
import createMuiTheme from '@material-ui/core/styles/createMuiTheme';
import flush from 'styled-jsx/server';
import getDisplayName from '../util/getDisplayName';
/**
 * Enable material-ui in nextjs._document.
 * DocumentComponent: next/document.
 * @param {MUITheme} theme
 * @param {next/document} DocumentComponent
 */

const extendsWithMui = themeInput => DocumentComponent => {
  // wrap de
  const theme = createMuiTheme(themeInput);

  class ExtendsWithMui extends DocumentComponent {
    static async getInitialProps(ctx) {
      // Resolution order
      //
      // On the server:
      // 1. app.getInitialProps
      // 2. page.getInitialProps
      // 3. document.getInitialProps
      // 4. app.render
      // 5. page.render
      // 6. document.render
      //
      // On the server with error:
      // 1. document.getInitialProps
      // 2. app.render
      // 3. page.render
      // 4. document.render
      //
      // On the client
      // 1. app.getInitialProps
      // 2. page.getInitialProps
      // 3. app.render
      // 4. page.render
      // inject theme by hoc
      const sheets = new ServerStyleSheets();
      const originalRenderPage = ctx.renderPage;

      ctx.renderPage = () => originalRenderPage({
        // wrap Jss context
        enhanceApp: App => props => sheets.collect(React.createElement(App, props))
      }); // get props after override the renderPage to get jss props


      const superProps = await super.getInitialProps(ctx); // push to head instead of override styles

      superProps.head.push(React.createElement(React.Fragment, {
        key: "jss-server-side"
      }, sheets.getStyleElement(), flush() || null));
      return _objectSpread({}, superProps);
    }

    render() {
      return React.createElement("html", {
        lang: "en"
      }, React.createElement(Head, null, React.createElement("meta", {
        charSet: "utf-8"
      }), React.createElement("meta", {
        name: "viewport",
        content: "minimum-scale=1, initial-scale=1, width=device-width, shrink-to-fit=no"
      }), React.createElement("meta", {
        name: "theme-color",
        content: theme.palette.primary.main
      }), React.createElement("link", {
        rel: "stylesheet",
        href: "https://fonts.googleapis.com/css?family=Roboto:300,400,500"
      })), React.createElement("body", null, React.createElement(Main, null), React.createElement(NextScript, null)));
    }

  }

  _defineProperty(ExtendsWithMui, "displayName", `extendsWithMui(${getDisplayName(DocumentComponent)})`);

  return ExtendsWithMui;
};

export default extendsWithMui;